@@ -8,7 +8,6 @@
   cases as published by the Free Software Foundation.
 */
 
-#include <openssl/md5.h>
 #include <inttypes.h>
 
 #include "glusterfs/call-stub.h"
@@ -1853,7 +1852,12 @@ out:
     return stub;
 }
 
-void
+/*
+ * Sometimes we might want to call just this, perhaps repeatedly, without
+ * having (or being able) to destroy and recreate it.
+ */
+
+static void
 call_resume_wind(call_stub_t *stub)
 {
     GF_VALIDATE_OR_GOTO("call-stub", stub, out);
@@ -2375,7 +2379,6 @@ call_resume(call_stub_t *stub)
 {
     xlator_t *old_THIS = NULL;
 
-    errno = EINVAL;
     GF_VALIDATE_OR_GOTO("call-stub", stub, out);
 
     list_del_init(&stub->list);
@@ -2441,7 +2444,6 @@ call_resume_keep_stub(call_stub_t *stub)
 {
     xlator_t *old_THIS = NULL;
 
-    errno = EINVAL;
     GF_VALIDATE_OR_GOTO("call-stub", stub, out);
 
     list_del_init(&stub->list);
