@@ -8,12 +8,8 @@
  * cases as published by the Free Software Foundation.
  */
 
-#include <glusterfs/defaults.h>
-#include "rpcsvc.h"
 #include <glusterfs/dict.h>
-#include <glusterfs/xlator.h>
 #include "nfs.h"
-#include <glusterfs/mem-pool.h>
 #include <glusterfs/logging.h>
 #include "nfs-fops.h"
 #include "nfs3.h"
@@ -22,7 +18,6 @@
 #include "nfs3-fh.h"
 #include "nfs-generics.h"
 #include "acl3.h"
-#include <glusterfs/byte-order.h>
 #include <glusterfs/compat-errno.h>
 #include "nfs-messages.h"
 
@@ -571,6 +566,12 @@ acl3_setacl_resume(void *carg)
     acl3_check_fh_resolve_status(cs, stat, acl3err);
     nfs_request_user_init(&nfu, cs->req);
     xattr = dict_new();
+    if (xattr == NULL) {
+        gf_msg(GF_NLM, GF_LOG_ERROR, ENOMEM, NFS_MSG_GFID_DICT_CREATE_FAIL,
+               "dict allocation failed");
+        goto acl3err;
+    }
+
     if (cs->aclcount)
         ret = dict_set_static_bin(xattr, POSIX_ACL_ACCESS_XATTR, cs->aclxattr,
                                   posix_acl_xattr_size(cs->aclcount));
@@ -701,13 +702,13 @@ rpcerr:
     return ret;
 }
 
-rpcsvc_actor_t acl3svc_actors[ACL3_PROC_COUNT] = {
-    {"NULL", ACL3_NULL, acl3svc_null, NULL, 0, DRC_NA},
-    {"GETACL", ACL3_GETACL, acl3svc_getacl, NULL, 0, DRC_NA},
-    {"SETACL", ACL3_SETACL, acl3svc_setacl, NULL, 0, DRC_NA},
+static rpcsvc_actor_t acl3svc_actors[ACL3_PROC_COUNT] = {
+    {"NULL", acl3svc_null, NULL, ACL3_NULL, DRC_NA, 0},
+    {"GETACL", acl3svc_getacl, NULL, ACL3_GETACL, DRC_NA, 0},
+    {"SETACL", acl3svc_setacl, NULL, ACL3_SETACL, DRC_NA, 0},
 };
 
-rpcsvc_program_t acl3prog = {
+static rpcsvc_program_t acl3prog = {
     .progname = "ACL3",
     .prognum = ACL_PROGRAM,
     .progver = ACLV3_VERSION,
@@ -724,7 +725,6 @@ acl3svc_init(xlator_t *nfsx)
     struct nfs_state *nfs = NULL;
     dict_t *options = NULL;
     int ret = -1;
-    char *portstr = NULL;
     static gf_boolean_t acl3_inited = _gf_false;
 
     /* Already inited */
@@ -742,12 +742,13 @@ acl3svc_init(xlator_t *nfsx)
     acl3prog.private = ns;
 
     options = dict_new();
-
-    ret = gf_asprintf(&portstr, "%d", GF_ACL3_PORT);
-    if (ret == -1)
+    if (options == NULL) {
+        gf_msg(GF_ACL, GF_LOG_ERROR, ENOMEM, NFS_MSG_GFID_DICT_CREATE_FAIL,
+               "dict allocation failed");
         goto err;
+    }
 
-    ret = dict_set_dynstr(options, "transport.socket.listen-port", portstr);
+    ret = dict_set_str(options, "transport.socket.listen-port", GF_ACL3_PORT);
     if (ret == -1)
         goto err;
     ret = dict_set_str(options, "transport-type", "socket");
@@ -783,7 +784,6 @@ acl3svc_init(xlator_t *nfsx)
     if (ret == -1) {
         gf_msg(GF_ACL, GF_LOG_ERROR, errno, NFS_MSG_LISTENERS_CREATE_FAIL,
                "Unable to create listeners");
-        dict_unref(options);
         goto err;
     }
 
